@@ -49,5 +49,8 @@ cdb_check_species <- function(cdb, species, return_db = FALSE) {
 
 # Utility function
 findSpecies <- function(species, db) {
-  tolower(species) %in% tolower(gsub("_", " ", db$SpeciesAccepted))
+  tolower(species) %in% tolower(gsub("_", " ",
+    db$SpeciesAccepted,
+    fixed = TRUE
+  ))
 }
