@@ -2,10 +2,16 @@
 #'
 #' @description
 #' Calculates an element-wise mean over a list of matrices or CompadreMat
-#' objects of constant dimension.
+#' objects of constant dimension. 
+#' 
+#' The difference between function \code{mat_mean}) and (\code{mpm_mean} is that
+#' \code{mat_mean} takes input as a list of matrices (e.g., a list of **A**
+#' matrices) while \code{mat_mean} takes input as a list of `CompadreMat` objects and
+#' thus calculates the mean matrices for both the **A** matrix and its
+#' submatrices (**U**, **F**, **C**).
 #'
-#' @param x List of matrices (\code{mat_mean}) or list of CompadreMat objects
-#'   (\code{mpm_mean}), all of same dimension
+#' @param x A list of matrices or, for \code{mpm_mean} a list of `CompadreMat` objects,
+#'   all of the same dimension
 #' @param na.rm Logical indicating whether missing values should be excluded
 #'   (see \emph{Details}). Defaults to \code{FALSE}.
 #'
@@ -27,6 +33,11 @@
 #' @examples
 #' # there are four rows for species 'Haplopappus_radiatus' in Compadre
 #' mpms <- Compadre$mat[Compadre$SpeciesAuthor == "Haplopappus_radiatus"]
+#' 
+#' #The object mpms is a list, containing compadre objects
+#' class(mpms)
+#' class(mpms[[1]])
+#' 
 #' mpm_mean(mpms)
 #'
 #' # extract list of matA and take mean
@@ -39,9 +50,16 @@ NULL
 #' @rdname mpm_mean
 #' @export
 mat_mean <- function(x, na.rm = FALSE) {
+  if(!inherits(x,"list")){
+    stop("x must be a list of matrices")
+  }
+  if(!inherits(x[[1]], "matrix")){
+    stop("x must be a list of matrices")
+  }
+  
   n_row <- vapply(x, nrow, numeric(1))
   n_col <- vapply(x, ncol, numeric(1))
-  if (length(unique(n_row)) != 1 | length(unique(n_col)) != 1) {
+  if (length(unique(n_row)) != 1 || length(unique(n_col)) != 1) {
     stop("All matrices in list must be of same dimension")
   }
   if (na.rm) x <- lapply(x, zero_NA)
@@ -61,6 +79,14 @@ zero_NA <- function(m) {
 #' @importFrom methods new
 #' @export
 mpm_mean <- function(x, na.rm = FALSE) {
+  if(!inherits(x, "list")){
+    stop("x must be a list of CompadreMat objects")
+  }
+  if(!inherits(x[[1]], "CompadreMat")){
+    stop("x must be a list of CompadreMat objects")
+  }
+  
+  #Use lapply to get matrices, stages when x is a list of compadre objects
   matA <- lapply(x, function(m) m@matA)
   matU <- lapply(x, function(m) m@matU)
   matF <- lapply(x, function(m) m@matF)
