@@ -6,7 +6,7 @@ test_that("cdb_id_studies works correctly", {
   s2 <- cdb_id_studies(Compadre, c("Family", "MatrixPopulation"))
   expect_type(s2, "integer")
   expect_length(s2, nrow(Compadre@data))
-  expect_true(!all(s1 == s2))
+  expect_false(all(s1 == s2))
 })
 
 
