@@ -2,7 +2,7 @@ test_that("cdb_mean_matF works correctly", {
   x <- cdb_mean_matF(Compadre)
 
   expect_type(x, "list")
-  expect_true("matrix" %in% class(x[[1]]))
+  expect_true(inherits(x[[1]], "matrix"))
   expect_length(x, nrow(Compadre@data))
 })
 
